# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/common.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'deephaven_enterprise/proto/common.proto\x12\x19io.deephaven.proto.common\"\x1c\n\x0b\x41uthRequest\x12\r\n\x05token\x18\x01 \x01(\x0c\"$\n\tAuthReply\x12\x17\n\x0fisAuthenticated\x18\x01 \x01(\x08\"\x0e\n\x0c\x41\x62outRequest\"<\n\nAboutReply\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"<\n\x0bPingRequest\x12\x1f\n\x17sender_send_time_millis\x18\x01 \x01(\x10\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\"B\n\x0cPingResponse\x12$\n\x1creceiver_receive_time_millis\x18\x01 \x01(\x10\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\"X\n\x17\x45xceptionDetailsMessage\x12\x14\n\x0c\x65rrorMessage\x18\x01 \x01(\t\x12\x12\n\nstackTrace\x18\x02 \x01(\t\x12\x13\n\x0bshortCauses\x18\x03 \x01(\t*3\n\x10NamespaceSetEnum\x12\t\n\x05UNSET\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x08\n\x04USER\x10\x02\x42\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_NAMESPACESETENUM']._serialized_start=436
  _globals['_NAMESPACESETENUM']._serialized_end=487
  _globals['_AUTHREQUEST']._serialized_start=70
  _globals['_AUTHREQUEST']._serialized_end=98
  _globals['_AUTHREPLY']._serialized_start=100
  _globals['_AUTHREPLY']._serialized_end=136
  _globals['_ABOUTREQUEST']._serialized_start=138
  _globals['_ABOUTREQUEST']._serialized_end=152
  _globals['_ABOUTREPLY']._serialized_start=154
  _globals['_ABOUTREPLY']._serialized_end=214
  _globals['_PINGREQUEST']._serialized_start=216
  _globals['_PINGREQUEST']._serialized_end=276
  _globals['_PINGRESPONSE']._serialized_start=278
  _globals['_PINGRESPONSE']._serialized_end=344
  _globals['_EXCEPTIONDETAILSMESSAGE']._serialized_start=346
  _globals['_EXCEPTIONDETAILSMESSAGE']._serialized_end=434
# @@protoc_insertion_point(module_scope)
