# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/acl.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deephaven_enterprise.proto import auth_pb2 as deephaven__enterprise_dot_proto_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$deephaven_enterprise/proto/acl.proto\x12\x1dio.deephaven.proto.controller\x1a%deephaven_enterprise/proto/auth.proto\"V\n\x10UnaryUserRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext\"2\n\x11UnaryGroupRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\r\n\x05group\x18\x02 \x01(\t\"!\n\x0f\x42ooleanResponse\x12\x0e\n\x06isTrue\x18\x01 \x01(\x08\"8\n\x0fUserOrGroupList\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x15\n\rusersOrGroups\x18\x02 \x03(\t\"$\n\x12GetAllUsersRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\"%\n\x13GetAllGroupsRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x42\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.acl_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_UNARYUSERREQUEST']._serialized_start=110
  _globals['_UNARYUSERREQUEST']._serialized_end=196
  _globals['_UNARYGROUPREQUEST']._serialized_start=198
  _globals['_UNARYGROUPREQUEST']._serialized_end=248
  _globals['_BOOLEANRESPONSE']._serialized_start=250
  _globals['_BOOLEANRESPONSE']._serialized_end=283
  _globals['_USERORGROUPLIST']._serialized_start=285
  _globals['_USERORGROUPLIST']._serialized_end=341
  _globals['_GETALLUSERSREQUEST']._serialized_start=343
  _globals['_GETALLUSERSREQUEST']._serialized_end=379
  _globals['_GETALLGROUPSREQUEST']._serialized_start=381
  _globals['_GETALLGROUPSREQUEST']._serialized_end=418
# @@protoc_insertion_point(module_scope)
