# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/table_definition.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1deephaven_enterprise/proto/table_definition.proto\x12\x19io.deephaven.proto.common\"\x9c\x03\n\x17\x43olumnDefinitionMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61taType\x18\x02 \x01(\t\x12\x1a\n\rcomponentType\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x42\n\ncolumnType\x18\x04 \x01(\x0e\x32).io.deephaven.proto.common.ColumnTypeEnumH\x01\x88\x01\x01\x12\x17\n\x0fisVarSizeString\x18\x05 \x01(\x08\x12\x42\n\x08\x65ncoding\x18\x06 \x01(\x0e\x32+.io.deephaven.proto.common.EncodingTypeEnumH\x02\x88\x01\x01\x12\x12\n\x05\x63odec\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x16\n\tcodecArgs\x18\x08 \x01(\tH\x04\x88\x01\x01\x12\x1d\n\x10objectWidthBytes\x18\t \x01(\x05H\x05\x88\x01\x01\x42\x10\n\x0e_componentTypeB\r\n\x0b_columnTypeB\x0b\n\t_encodingB\x08\n\x06_codecB\x0c\n\n_codecArgsB\x13\n\x11_objectWidthBytes\"\xff\x01\n\x16TableDefinitionMessage\x12\x16\n\tnamespace\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\ttableName\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x43\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x32.io.deephaven.proto.common.ColumnDefinitionMessage\x12\x44\n\x0bstorageType\x18\x04 \x01(\x0e\x32*.io.deephaven.proto.common.StorageTypeEnumH\x02\x88\x01\x01\x42\x0c\n\n_namespaceB\x0c\n\n_tableNameB\x0e\n\x0c_storageType*\x83\x01\n\x0fStorageTypeEnum\x12\x12\n\x0eST_UNSPECIFIED\x10\x00\x12\x10\n\x0cST_IN_MEMORY\x10\x01\x12!\n\x1dST_NESTED_PARTITIONED_ON_DISK\x10\x02\x12\x16\n\x12ST_SPLAYED_ON_DISK\x10\x04\x12\x0f\n\x0bST_EXTENDED\x10\x08*i\n\x0e\x43olumnTypeEnum\x12\x12\n\x0e\x43T_UNSPECIFIED\x10\x00\x12\r\n\tCT_NORMAL\x10\x01\x12\x0f\n\x0b\x43T_GROUPING\x10\x02\x12\x13\n\x0f\x43T_PARTITIONING\x10\x04\x12\x0e\n\nCT_VIRTUAL\x10\x08*\x89\x01\n\x10\x45ncodingTypeEnum\x12\x12\n\x0e\x45T_UNSPECIFIED\x10\x00\x12\x11\n\rET_ISO_8859_1\x10\x01\x12\x0c\n\x08\x45T_UTF_8\x10\x02\x12\x0f\n\x0b\x45T_US_ASCII\x10\x04\x12\r\n\tET_UTF_16\x10\x08\x12\x0f\n\x0b\x45T_UTF_16BE\x10\x10\x12\x0f\n\x0b\x45T_UTF_16LE\x10 B\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.table_definition_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_STORAGETYPEENUM']._serialized_start=754
  _globals['_STORAGETYPEENUM']._serialized_end=885
  _globals['_COLUMNTYPEENUM']._serialized_start=887
  _globals['_COLUMNTYPEENUM']._serialized_end=992
  _globals['_ENCODINGTYPEENUM']._serialized_start=995
  _globals['_ENCODINGTYPEENUM']._serialized_end=1132
  _globals['_COLUMNDEFINITIONMESSAGE']._serialized_start=81
  _globals['_COLUMNDEFINITIONMESSAGE']._serialized_end=493
  _globals['_TABLEDEFINITIONMESSAGE']._serialized_start=496
  _globals['_TABLEDEFINITIONMESSAGE']._serialized_end=751
# @@protoc_insertion_point(module_scope)
