# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/controller_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deephaven_enterprise.proto import controller_common_pb2 as deephaven__enterprise_dot_proto_dot_controller__common__pb2
from deephaven_enterprise.proto import controller_pb2 as deephaven__enterprise_dot_proto_dot_controller__pb2
from deephaven_enterprise.proto import acl_pb2 as deephaven__enterprise_dot_proto_dot_acl__pb2
from deephaven_enterprise.proto import auth_pb2 as deephaven__enterprise_dot_proto_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3deephaven_enterprise/proto/controller_service.proto\x12\"io.deephaven.proto.controller.grpc\x1a\x32\x64\x65\x65phaven_enterprise/proto/controller_common.proto\x1a+deephaven_enterprise/proto/controller.proto\x1a$deephaven_enterprise/proto/acl.proto\x1a%deephaven_enterprise/proto/auth.proto2\xd6\x12\n\rControllerApi\x12}\n\x0c\x61uthenticate\x12\x34.io.deephaven.proto.controller.AuthenticationRequest\x1a\x35.io.deephaven.proto.controller.AuthenticationResponse\"\x00\x12m\n\x08\x61\x64\x64Query\x12..io.deephaven.proto.controller.AddQueryRequest\x1a/.io.deephaven.proto.controller.AddQueryResponse\"\x00\x12v\n\x0bremoveQuery\x12\x31.io.deephaven.proto.controller.RemoveQueryRequest\x1a\x32.io.deephaven.proto.controller.RemoveQueryResponse\"\x00\x12v\n\x0bmodifyQuery\x12\x31.io.deephaven.proto.controller.ModifyQueryRequest\x1a\x32.io.deephaven.proto.controller.ModifyQueryResponse\"\x00\x12y\n\x0crestartQuery\x12\x32.io.deephaven.proto.controller.RestartQueryRequest\x1a\x33.io.deephaven.proto.controller.RestartQueryResponse\"\x00\x12p\n\tstopQuery\x12/.io.deephaven.proto.controller.StopQueryRequest\x1a\x30.io.deephaven.proto.controller.StopQueryResponse\"\x00\x12\x7f\n\x0erestartReplica\x12\x34.io.deephaven.proto.controller.RestartReplicaRequest\x1a\x35.io.deephaven.proto.controller.RestartReplicaResponse\"\x00\x12v\n\x0bstopReplica\x12\x31.io.deephaven.proto.controller.StopReplicaRequest\x1a\x32.io.deephaven.proto.controller.StopReplicaResponse\"\x00\x12\x8e\x01\n\x13\x64\x65termineDispatcher\x12\x39.io.deephaven.proto.controller.DetermineDispatcherRequest\x1a:.io.deephaven.proto.controller.DetermineDispatcherResponse\"\x00\x12\x96\x01\n\x17selectionProviderStatus\x12;.io.deephaven.proto.controller.ServerSelectionStatusRequest\x1a<.io.deephaven.proto.controller.ServerSelectionStatusResponse\"\x00\x12\x93\x01\n\x16selectionProviderAdmin\x12:.io.deephaven.proto.controller.ServerSelectionAdminRequest\x1a;.io.deephaven.proto.controller.ServerSelectionAdminResponse\"\x00\x12\x85\x01\n\x10getConfiguration\x12\x36.io.deephaven.proto.controller.GetConfigurationRequest\x1a\x37.io.deephaven.proto.controller.GetConfigurationResponse\"\x00\x12\x7f\n\x0egetScriptPaths\x12\x34.io.deephaven.proto.controller.GetScriptPathsRequest\x1a\x35.io.deephaven.proto.controller.GetScriptPathsResponse\"\x00\x12p\n\tgetScript\x12/.io.deephaven.proto.controller.GetScriptRequest\x1a\x30.io.deephaven.proto.controller.GetScriptResponse\"\x00\x12y\n\x0cstatusUpdate\x12\x32.io.deephaven.proto.controller.StatusUpdateRequest\x1a\x33.io.deephaven.proto.controller.StatusUpdateResponse\"\x00\x12y\n\x0creloadConfig\x12\x32.io.deephaven.proto.controller.ReloadConfigRequest\x1a\x33.io.deephaven.proto.controller.ReloadConfigResponse\"\x00\x12\x61\n\x04ping\x12*.io.deephaven.proto.controller.PingRequest\x1a+.io.deephaven.proto.controller.PingResponse\"\x00\x12r\n\tsubscribe\x12/.io.deephaven.proto.controller.SubscribeRequest\x1a\x30.io.deephaven.proto.controller.SubscribeResponse\"\x00\x30\x01\x12y\n\x10invalidateCookie\x12\x30.io.deephaven.proto.auth.InvalidateCookieRequest\x1a\x31.io.deephaven.proto.auth.InvalidateCookieResponse\"\x00\x32\xb0\x07\n\x06\x41\x63lApi\x12p\n\x0bisSuperUser\x12/.io.deephaven.proto.controller.UnaryUserRequest\x1a..io.deephaven.proto.controller.BooleanResponse\"\x00\x12p\n\x0bisAclEditor\x12/.io.deephaven.proto.controller.UnaryUserRequest\x1a..io.deephaven.proto.controller.BooleanResponse\"\x00\x12s\n\x0eisQueryManager\x12/.io.deephaven.proto.controller.UnaryUserRequest\x1a..io.deephaven.proto.controller.BooleanResponse\"\x00\x12t\n\x0fisSchemaManager\x12/.io.deephaven.proto.controller.UnaryUserRequest\x1a..io.deephaven.proto.controller.BooleanResponse\"\x00\x12v\n\x10getUsersForGroup\x12\x30.io.deephaven.proto.controller.UnaryGroupRequest\x1a..io.deephaven.proto.controller.UserOrGroupList\"\x00\x12u\n\x10getGroupsForUser\x12/.io.deephaven.proto.controller.UnaryUserRequest\x1a..io.deephaven.proto.controller.UserOrGroupList\"\x00\x12r\n\x0bgetAllUsers\x12\x31.io.deephaven.proto.controller.GetAllUsersRequest\x1a..io.deephaven.proto.controller.UserOrGroupList\"\x00\x12t\n\x0cgetAllGroups\x12\x32.io.deephaven.proto.controller.GetAllGroupsRequest\x1a..io.deephaven.proto.controller.UserOrGroupList\"\x00\x42\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.controller_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_CONTROLLERAPI']._serialized_start=266
  _globals['_CONTROLLERAPI']._serialized_end=2656
  _globals['_ACLAPI']._serialized_start=2659
  _globals['_ACLAPI']._serialized_end=3603
# @@protoc_insertion_point(module_scope)
