# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/controller.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deephaven_enterprise.proto import auth_pb2 as deephaven__enterprise_dot_proto_dot_auth__pb2
from deephaven_enterprise.proto import controller_common_pb2 as deephaven__enterprise_dot_proto_dot_controller__common__pb2
from deephaven_enterprise.proto import persistent_query_pb2 as deephaven__enterprise_dot_proto_dot_persistent__query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+deephaven_enterprise/proto/controller.proto\x12\x1dio.deephaven.proto.controller\x1a%deephaven_enterprise/proto/auth.proto\x1a\x32\x64\x65\x65phaven_enterprise/proto/controller_common.proto\x1a\x31\x64\x65\x65phaven_enterprise/proto/persistent_query.proto\"\x95\x01\n\x15\x41uthenticationRequest\x12-\n\x05token\x18\x01 \x01(\x0b\x32\x1e.io.deephaven.proto.auth.Token\x12\x33\n\x08\x63lientId\x18\x02 \x01(\x0b\x32!.io.deephaven.proto.auth.ClientId\x12\x18\n\x10getConfiguration\x18\x03 \x01(\x08\"\x9e\x01\n\x16\x41uthenticationResponse\x12\x15\n\rauthenticated\x18\x01 \x01(\x08\x12\x0e\n\x06\x63ookie\x18\x02 \x01(\x0c\x12R\n\x06\x63onfig\x18\x03 \x01(\x0b\x32=.io.deephaven.proto.controller.ControllerConfigurationMessageH\x00\x88\x01\x01\x42\t\n\x07_config\"n\n\x0f\x41\x64\x64QueryRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12K\n\x06\x63onfig\x18\x02 \x01(\x0b\x32;.io.deephaven.proto.controller.PersistentQueryConfigMessage\"\'\n\x10\x41\x64\x64QueryResponse\x12\x13\n\x0bquerySerial\x18\x01 \x01(\x03\"4\n\x12RemoveQueryRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x0e\n\x06serial\x18\x02 \x01(\x03\"\x15\n\x13RemoveQueryResponse\"\x84\x01\n\x12ModifyQueryRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12K\n\x06\x63onfig\x18\x02 \x01(\x0b\x32;.io.deephaven.proto.controller.PersistentQueryConfigMessage\x12\x11\n\tdoRestart\x18\x03 \x01(\x08\"\x15\n\x13ModifyQueryResponse\"z\n\x10ReplicaSpecifier\x12\x0e\n\x06serial\x18\x01 \x01(\x03\x12\x11\n\x07replica\x18\x02 \x01(\x05H\x00\x12\x0f\n\x05spare\x18\x03 \x01(\x05H\x00\x12\x1a\n\rprocessInfoId\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x04\n\x02idB\x10\n\x0e_processInfoId\"\x80\x01\n\rReplicaStatus\x12@\n\x07replica\x18\x01 \x01(\x0b\x32/.io.deephaven.proto.controller.ReplicaSpecifier\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x12\n\x05\x65rror\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_error\"j\n\x15RestartReplicaRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x41\n\x08replicas\x18\x02 \x03(\x0b\x32/.io.deephaven.proto.controller.ReplicaSpecifier\"V\n\x16RestartReplicaResponse\x12<\n\x06status\x18\x01 \x03(\x0b\x32,.io.deephaven.proto.controller.ReplicaStatus\"g\n\x12StopReplicaRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x41\n\x08replicas\x18\x02 \x03(\x0b\x32/.io.deephaven.proto.controller.ReplicaSpecifier\"S\n\x13StopReplicaResponse\x12<\n\x06status\x18\x01 \x03(\x0b\x32,.io.deephaven.proto.controller.ReplicaStatus\"6\n\x13RestartQueryRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x0f\n\x07serials\x18\x02 \x03(\x03\"\xc0\x01\n\x14RestartQueryResponse\x12\x16\n\x0esuccessSerials\x18\x01 \x03(\x03\x12[\n\x0c\x65rrorSerials\x18\x02 \x03(\x0b\x32\x45.io.deephaven.proto.controller.RestartQueryResponse.ErrorSerialsEntry\x1a\x33\n\x11\x45rrorSerialsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x10StopQueryRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x0f\n\x07serials\x18\x02 \x03(\x03\"\xba\x01\n\x11StopQueryResponse\x12\x16\n\x0esuccessSerials\x18\x01 \x03(\x03\x12X\n\x0c\x65rrorSerials\x18\x02 \x03(\x0b\x32\x42.io.deephaven.proto.controller.StopQueryResponse.ErrorSerialsEntry\x1a\x33\n\x11\x45rrorSerialsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"m\n\x1a\x44\x65termineDispatcherRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x17\n\x0fserverGroupName\x18\x02 \x01(\t\x12\x12\n\nheapSizeMb\x18\x03 \x01(\x05\x12\x12\n\nworkerKind\x18\x04 \x01(\t\"k\n\x1b\x44\x65termineDispatcherResponse\x12L\n\x0cserverConfig\x18\x01 \x01(\x0b\x32\x36.io.deephaven.proto.controller.PQDBServerConfigMessage\"\xb7\x02\n\x17PQDBServerConfigMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12&\n\x19\x63lassPushListResourceName\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bserverClass\x18\x05 \x01(\t\x12\x15\n\rmaxHeapSizeGb\x18\x06 \x01(\x01\x12\x41\n\nserverType\x18\x07 \x01(\x0e\x32-.io.deephaven.proto.controller.ServerTypeEnum\x12\x15\n\rconsoleGroups\x18\x08 \x03(\t\x12\x17\n\nserverInfo\x18\t \x01(\tH\x01\x88\x01\x01\x42\x1c\n\x1a_classPushListResourceNameB\r\n\x0b_serverInfo\"\x87\x01\n\x1d\x41ssignmentPolicyConfigMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x02 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x11\x61\x63\x63\x65ptsParameters\x18\x04 \x01(\x08\x42\x0e\n\x0c_description\")\n\x17GetConfigurationRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\"i\n\x18GetConfigurationResponse\x12M\n\x06\x63onfig\x18\x01 \x01(\x0b\x32=.io.deephaven.proto.controller.ControllerConfigurationMessage\"\xc7\x08\n\x1e\x43ontrollerConfigurationMessage\x12\x15\n\rmaxHeapSizeGb\x18\x01 \x01(\x05\x12\x1e\n\x16minDataBufferPoolRatio\x18\x02 \x01(\x01\x12\x1e\n\x16maxDataBufferPoolRatio\x18\x03 \x01(\x01\x12Z\n\x12\x63onfigurationTypes\x18\x04 \x03(\x0b\x32>.io.deephaven.proto.controller.ConsoleConfigurationTypeMessage\x12_\n\x15temporaryQueueDetails\x18\x05 \x03(\x0b\x32@.io.deephaven.proto.controller.ControllerTempQueueDetailsMessage\x12\x1c\n\x14\x64\x65\x66\x61ultTempQueueName\x18\x06 \x01(\t\x12I\n\tdbServers\x18\x07 \x03(\x0b\x32\x36.io.deephaven.proto.controller.PQDBServerConfigMessage\x12 \n\x18\x64\x65\x66\x61ultSchedulingDetails\x18\x08 \x03(\t\x12\x1f\n\x17scheduleLookForwardDays\x18\t \x01(\x05\x12\x11\n\tpublicKey\x18\n \x01(\x0c\x12\x11\n\talgorithm\x18\x0b \x01(\t\x12K\n\x13\x63onsoleServerGroups\x18\x0c \x03(\x0b\x32..io.deephaven.proto.controller.NamedStringList\x12\x17\n\x0fjvmProfileNames\x18\r \x03(\t\x12\x1d\n\x15\x64\x65\x66\x61ultJvmProfileName\x18\x0e \x01(\t\x12\x1b\n\x13\x64\x61taRoutingImplName\x18\x0f \x01(\t\x12G\n\ntdsConfigs\x18\x10 \x03(\x0b\x32\x33.io.deephaven.proto.controller.RoutingConfigMessage\x12G\n\ndisConfigs\x18\x11 \x03(\x0b\x32\x33.io.deephaven.proto.controller.RoutingConfigMessage\x12G\n\nlasConfigs\x18\x12 \x03(\x0b\x32\x33.io.deephaven.proto.controller.RoutingConfigMessage\x12X\n\x12\x61ssignmentPolicies\x18\x14 \x03(\x0b\x32<.io.deephaven.proto.controller.AssignmentPolicyConfigMessage\x12#\n\x1b\x64\x65\x66\x61ultAssignmentPolicyName\x18\x15 \x01(\t\x12%\n\x1d\x64\x65\x66\x61ultAssignmentPolicyParams\x18\x16 \x01(\tJ\x04\x08\x13\x10\x14R\x16inWorkerServiceDetails\"G\n\x14RoutingConfigMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"b\n!ControllerTempQueueDetailsMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1c\n\x14maxConcurrentQueries\x18\x02 \x01(\x05\x12\x11\n\tmaxHeapMb\x18\x03 \x01(\x05\"\x85\x07\n\x1f\x43onsoleConfigurationTypeMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x02 \x01(\t\x12\x13\n\x0b\x64isplayable\x18\x03 \x01(\x08\x12\x62\n\nproperties\x18\x04 \x03(\x0b\x32N.io.deephaven.proto.controller.ConsoleConfigurationTypeMessage.PropertiesEntry\x12\x11\n\thasScript\x18\x05 \x01(\x08\x12\x15\n\rserverClasses\x18\x06 \x03(\t\x12\x15\n\rallowedGroups\x18\x07 \x03(\t\x12G\n\x0c\x65xtraColumns\x18\x08 \x03(\x0b\x32\x31.io.deephaven.proto.controller.ExtraColumnMessage\x12\'\n\x1atypeSpecificWireConfigJSON\x18\t \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12\x63onfigCheckerClass\x18\n \x01(\t\x12\x1f\n\x17\x63onfigPanelFactoryClass\x18\x0b \x01(\t\x12!\n\x19\x63ustomActionProviderClass\x18\x0c \x01(\t\x12\x17\n\x0fsetupQueryClass\x18\r \x01(\t\x12\x13\n\x0b\x63onfigClass\x18\x0e \x01(\t\x12\x1e\n\x16shutdownProcedureClass\x18\x0f \x01(\t\x12\x19\n\x11\x65xtraJvmArgsClass\x18\x10 \x01(\t\x12\x1c\n\x14\x63onfigProcessorClass\x18\x11 \x01(\t\x12\x1e\n\x16\x65xtraColumnGetterClass\x18\x12 \x01(\t\x12\x1a\n\x12popupProviderClass\x18\x13 \x03(\t\x12\x1e\n\x16\x63onfigTypeDetailsClass\x18\x14 \x01(\t\x12!\n\x19\x63ommunityInitializerClass\x18\x15 \x01(\t\x12\x19\n\x11hasScriptLanguage\x18\x16 \x01(\x08\x12&\n\x1e\x63ommunityRequestProcessorClass\x18\x17 \x01(\t\x12\x18\n\x10supportsReplicas\x18\x18 \x01(\x08\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1d\n\x1b_typeSpecificWireConfigJSON\"8\n\x12\x45xtraColumnMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0crendererName\x18\x02 \x01(\t\".\n\x1cServerSelectionStatusRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\"/\n\x1dServerSelectionStatusResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\">\n\x1bServerSelectionAdminRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\".\n\x1cServerSelectionAdminResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x99\x02\n\x15GetScriptPathsRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x41\n\x07\x63ommand\x18\x02 \x01(\x0e\x32\x30.io.deephaven.proto.controller.ScriptCommandEnum\x12\x18\n\x0bquerySerial\x18\x03 \x01(\x03H\x00\x88\x01\x01\x12\x1a\n\reffectiveUser\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\"\n\x15scriptLoaderStateJSON\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x17\n\x0fuseRelativePath\x18\x06 \x01(\x08\x42\x0e\n\x0c_querySerialB\x10\n\x0e_effectiveUserB\x18\n\x16_scriptLoaderStateJSON\")\n\x16GetScriptPathsResponse\x12\x0f\n\x07results\x18\x01 \x03(\t\"\xa8\x02\n\x10GetScriptRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x41\n\x07\x63ommand\x18\x02 \x01(\x0e\x32\x30.io.deephaven.proto.controller.ScriptCommandEnum\x12\x18\n\x0bquerySerial\x18\x03 \x01(\x03H\x00\x88\x01\x01\x12\x1a\n\reffectiveUser\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\"\n\x15scriptLoaderStateJSON\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x12\n\nscriptPath\x18\x06 \x01(\t\x12\x17\n\x0fuseRelativePath\x18\x07 \x01(\x08\x42\x0e\n\x0c_querySerialB\x10\n\x0e_effectiveUserB\x18\n\x16_scriptLoaderStateJSON\";\n\x11GetScriptResponse\x12\x17\n\nscriptBody\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_scriptBody\"\xf7\x02\n\x13StatusUpdateRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x13\n\x0bquerySerial\x18\x02 \x01(\x03\x12M\n\x06status\x18\x03 \x01(\x0e\x32\x38.io.deephaven.proto.controller.PersistentQueryStatusEnumH\x00\x88\x01\x01\x12\x1a\n\x12hasExportedObjects\x18\x04 \x01(\x08\x12Q\n\x0f\x65xportedObjects\x18\x05 \x03(\x0b\x32\x38.io.deephaven.proto.controller.ExportedObjectInfoMessage\x12\x16\n\x0ehasTableGroups\x18\x06 \x01(\x08\x12\x43\n\x0btableGroups\x18\x07 \x03(\x0b\x32..io.deephaven.proto.controller.NamedStringList\x12\x15\n\rprocessInfoId\x18\x08 \x01(\tB\t\n\x07_status\"\x16\n\x14StatusUpdateResponse\"%\n\x13ReloadConfigRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\"\x16\n\x14ReloadConfigResponse\"\"\n\x10SubscribeRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\"\x94\x02\n\x11SubscribeResponse\x12?\n\x05\x65vent\x18\x01 \x01(\x0e\x32\x30.io.deephaven.proto.controller.SubscriptionEvent\x12\x15\n\x0bquerySerial\x18\x03 \x01(\x03H\x00\x12N\n\tqueryInfo\x18\x04 \x01(\x0b\x32\x39.io.deephaven.proto.controller.PersistentQueryInfoMessageH\x00\x12O\n\x06\x63onfig\x18\x05 \x01(\x0b\x32=.io.deephaven.proto.controller.ControllerConfigurationMessageH\x00\x42\x06\n\x04\x64\x61ta*H\n\x0eServerTypeEnum\x12\x13\n\x0fSTE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTE_DISPATCHER\x10\x01\x12\r\n\tSTE_GROUP\x10\x02*j\n\x11ScriptCommandEnum\x12\x13\n\x0fSCE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSCE_GET_AS_SELF\x10\x01\x12\x14\n\x10SCE_GET_AS_OTHER\x10\x02\x12\x15\n\x11SCE_GET_FOR_QUERY\x10\x03*j\n\x11SubscriptionEvent\x12\x12\n\x0eSE_UNSPECIFIED\x10\x00\x12\n\n\x06SE_PUT\x10\x01\x12\r\n\tSE_REMOVE\x10\x02\x12\x14\n\x10SE_CONFIG_UPDATE\x10\x03\x12\x10\n\x0cSE_BATCH_END\x10\x04\x42\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.controller_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_RESTARTQUERYRESPONSE_ERRORSERIALSENTRY']._loaded_options = None
  _globals['_RESTARTQUERYRESPONSE_ERRORSERIALSENTRY']._serialized_options = b'8\001'
  _globals['_STOPQUERYRESPONSE_ERRORSERIALSENTRY']._loaded_options = None
  _globals['_STOPQUERYRESPONSE_ERRORSERIALSENTRY']._serialized_options = b'8\001'
  _globals['_CONSOLECONFIGURATIONTYPEMESSAGE_PROPERTIESENTRY']._loaded_options = None
  _globals['_CONSOLECONFIGURATIONTYPEMESSAGE_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_SERVERTYPEENUM']._serialized_start=6786
  _globals['_SERVERTYPEENUM']._serialized_end=6858
  _globals['_SCRIPTCOMMANDENUM']._serialized_start=6860
  _globals['_SCRIPTCOMMANDENUM']._serialized_end=6966
  _globals['_SUBSCRIPTIONEVENT']._serialized_start=6968
  _globals['_SUBSCRIPTIONEVENT']._serialized_end=7074
  _globals['_AUTHENTICATIONREQUEST']._serialized_start=221
  _globals['_AUTHENTICATIONREQUEST']._serialized_end=370
  _globals['_AUTHENTICATIONRESPONSE']._serialized_start=373
  _globals['_AUTHENTICATIONRESPONSE']._serialized_end=531
  _globals['_ADDQUERYREQUEST']._serialized_start=533
  _globals['_ADDQUERYREQUEST']._serialized_end=643
  _globals['_ADDQUERYRESPONSE']._serialized_start=645
  _globals['_ADDQUERYRESPONSE']._serialized_end=684
  _globals['_REMOVEQUERYREQUEST']._serialized_start=686
  _globals['_REMOVEQUERYREQUEST']._serialized_end=738
  _globals['_REMOVEQUERYRESPONSE']._serialized_start=740
  _globals['_REMOVEQUERYRESPONSE']._serialized_end=761
  _globals['_MODIFYQUERYREQUEST']._serialized_start=764
  _globals['_MODIFYQUERYREQUEST']._serialized_end=896
  _globals['_MODIFYQUERYRESPONSE']._serialized_start=898
  _globals['_MODIFYQUERYRESPONSE']._serialized_end=919
  _globals['_REPLICASPECIFIER']._serialized_start=921
  _globals['_REPLICASPECIFIER']._serialized_end=1043
  _globals['_REPLICASTATUS']._serialized_start=1046
  _globals['_REPLICASTATUS']._serialized_end=1174
  _globals['_RESTARTREPLICAREQUEST']._serialized_start=1176
  _globals['_RESTARTREPLICAREQUEST']._serialized_end=1282
  _globals['_RESTARTREPLICARESPONSE']._serialized_start=1284
  _globals['_RESTARTREPLICARESPONSE']._serialized_end=1370
  _globals['_STOPREPLICAREQUEST']._serialized_start=1372
  _globals['_STOPREPLICAREQUEST']._serialized_end=1475
  _globals['_STOPREPLICARESPONSE']._serialized_start=1477
  _globals['_STOPREPLICARESPONSE']._serialized_end=1560
  _globals['_RESTARTQUERYREQUEST']._serialized_start=1562
  _globals['_RESTARTQUERYREQUEST']._serialized_end=1616
  _globals['_RESTARTQUERYRESPONSE']._serialized_start=1619
  _globals['_RESTARTQUERYRESPONSE']._serialized_end=1811
  _globals['_RESTARTQUERYRESPONSE_ERRORSERIALSENTRY']._serialized_start=1760
  _globals['_RESTARTQUERYRESPONSE_ERRORSERIALSENTRY']._serialized_end=1811
  _globals['_STOPQUERYREQUEST']._serialized_start=1813
  _globals['_STOPQUERYREQUEST']._serialized_end=1864
  _globals['_STOPQUERYRESPONSE']._serialized_start=1867
  _globals['_STOPQUERYRESPONSE']._serialized_end=2053
  _globals['_STOPQUERYRESPONSE_ERRORSERIALSENTRY']._serialized_start=1760
  _globals['_STOPQUERYRESPONSE_ERRORSERIALSENTRY']._serialized_end=1811
  _globals['_DETERMINEDISPATCHERREQUEST']._serialized_start=2055
  _globals['_DETERMINEDISPATCHERREQUEST']._serialized_end=2164
  _globals['_DETERMINEDISPATCHERRESPONSE']._serialized_start=2166
  _globals['_DETERMINEDISPATCHERRESPONSE']._serialized_end=2273
  _globals['_PQDBSERVERCONFIGMESSAGE']._serialized_start=2276
  _globals['_PQDBSERVERCONFIGMESSAGE']._serialized_end=2587
  _globals['_ASSIGNMENTPOLICYCONFIGMESSAGE']._serialized_start=2590
  _globals['_ASSIGNMENTPOLICYCONFIGMESSAGE']._serialized_end=2725
  _globals['_GETCONFIGURATIONREQUEST']._serialized_start=2727
  _globals['_GETCONFIGURATIONREQUEST']._serialized_end=2768
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_start=2770
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_end=2875
  _globals['_CONTROLLERCONFIGURATIONMESSAGE']._serialized_start=2878
  _globals['_CONTROLLERCONFIGURATIONMESSAGE']._serialized_end=3973
  _globals['_ROUTINGCONFIGMESSAGE']._serialized_start=3975
  _globals['_ROUTINGCONFIGMESSAGE']._serialized_end=4046
  _globals['_CONTROLLERTEMPQUEUEDETAILSMESSAGE']._serialized_start=4048
  _globals['_CONTROLLERTEMPQUEUEDETAILSMESSAGE']._serialized_end=4146
  _globals['_CONSOLECONFIGURATIONTYPEMESSAGE']._serialized_start=4149
  _globals['_CONSOLECONFIGURATIONTYPEMESSAGE']._serialized_end=5050
  _globals['_CONSOLECONFIGURATIONTYPEMESSAGE_PROPERTIESENTRY']._serialized_start=4970
  _globals['_CONSOLECONFIGURATIONTYPEMESSAGE_PROPERTIESENTRY']._serialized_end=5019
  _globals['_EXTRACOLUMNMESSAGE']._serialized_start=5052
  _globals['_EXTRACOLUMNMESSAGE']._serialized_end=5108
  _globals['_SERVERSELECTIONSTATUSREQUEST']._serialized_start=5110
  _globals['_SERVERSELECTIONSTATUSREQUEST']._serialized_end=5156
  _globals['_SERVERSELECTIONSTATUSRESPONSE']._serialized_start=5158
  _globals['_SERVERSELECTIONSTATUSRESPONSE']._serialized_end=5205
  _globals['_SERVERSELECTIONADMINREQUEST']._serialized_start=5207
  _globals['_SERVERSELECTIONADMINREQUEST']._serialized_end=5269
  _globals['_SERVERSELECTIONADMINRESPONSE']._serialized_start=5271
  _globals['_SERVERSELECTIONADMINRESPONSE']._serialized_end=5317
  _globals['_GETSCRIPTPATHSREQUEST']._serialized_start=5320
  _globals['_GETSCRIPTPATHSREQUEST']._serialized_end=5601
  _globals['_GETSCRIPTPATHSRESPONSE']._serialized_start=5603
  _globals['_GETSCRIPTPATHSRESPONSE']._serialized_end=5644
  _globals['_GETSCRIPTREQUEST']._serialized_start=5647
  _globals['_GETSCRIPTREQUEST']._serialized_end=5943
  _globals['_GETSCRIPTRESPONSE']._serialized_start=5945
  _globals['_GETSCRIPTRESPONSE']._serialized_end=6004
  _globals['_STATUSUPDATEREQUEST']._serialized_start=6007
  _globals['_STATUSUPDATEREQUEST']._serialized_end=6382
  _globals['_STATUSUPDATERESPONSE']._serialized_start=6384
  _globals['_STATUSUPDATERESPONSE']._serialized_end=6406
  _globals['_RELOADCONFIGREQUEST']._serialized_start=6408
  _globals['_RELOADCONFIGREQUEST']._serialized_end=6445
  _globals['_RELOADCONFIGRESPONSE']._serialized_start=6447
  _globals['_RELOADCONFIGRESPONSE']._serialized_end=6469
  _globals['_SUBSCRIBEREQUEST']._serialized_start=6471
  _globals['_SUBSCRIBEREQUEST']._serialized_end=6505
  _globals['_SUBSCRIBERESPONSE']._serialized_start=6508
  _globals['_SUBSCRIBERESPONSE']._serialized_end=6784
# @@protoc_insertion_point(module_scope)
