# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/auth_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deephaven_enterprise.proto import common_pb2 as deephaven__enterprise_dot_proto_dot_common__pb2
from deephaven_enterprise.proto import auth_pb2 as deephaven__enterprise_dot_proto_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-deephaven_enterprise/proto/auth_service.proto\x12\x1cio.deephaven.proto.auth.grpc\x1a\'deephaven_enterprise/proto/common.proto\x1a%deephaven_enterprise/proto/auth.proto2\x93\r\n\x07\x41uthApi\x12Y\n\x04ping\x12&.io.deephaven.proto.common.PingRequest\x1a\'.io.deephaven.proto.common.PingResponse\"\x00\x12\x8b\x01\n\x16\x61uthenticateByPassword\x12\x36.io.deephaven.proto.auth.AuthenticateByPasswordRequest\x1a\x37.io.deephaven.proto.auth.AuthenticateByPasswordResponse\"\x00\x12\x8e\x01\n\x17\x61uthenticateByPublicKey\x12\x37.io.deephaven.proto.auth.AuthenticateByPublicKeyRequest\x1a\x38.io.deephaven.proto.auth.AuthenticateByPublicKeyResponse\"\x00\x12\x9a\x01\n\x1b\x61uthenticateByDelegateToken\x12;.io.deephaven.proto.auth.AuthenticateByDelegateTokenRequest\x1a<.io.deephaven.proto.auth.AuthenticateByDelegateTokenResponse\"\x00\x12\x8b\x01\n\x16\x61uthenticateByExternal\x12\x36.io.deephaven.proto.auth.AuthenticateByExternalRequest\x1a\x37.io.deephaven.proto.auth.AuthenticateByExternalResponse\"\x00\x12\x85\x01\n\x14\x61uthenticateByCookie\x12\x34.io.deephaven.proto.auth.AuthenticateByCookieRequest\x1a\x35.io.deephaven.proto.auth.AuthenticateByCookieResponse\"\x00\x12p\n\rrefreshCookie\x12-.io.deephaven.proto.auth.RefreshCookieRequest\x1a..io.deephaven.proto.auth.RefreshCookieResponse\"\x00\x12y\n\x10invalidateCookie\x12\x30.io.deephaven.proto.auth.InvalidateCookieRequest\x1a\x31.io.deephaven.proto.auth.InvalidateCookieResponse\"\x00\x12\x61\n\x08getNonce\x12(.io.deephaven.proto.auth.GetNonceRequest\x1a).io.deephaven.proto.auth.GetNonceResponse\"\x00\x12\x61\n\x08getToken\x12(.io.deephaven.proto.auth.GetTokenRequest\x1a).io.deephaven.proto.auth.GetTokenResponse\"\x00\x12g\n\ngetTokenAs\x12*.io.deephaven.proto.auth.GetTokenAsRequest\x1a+.io.deephaven.proto.auth.GetTokenAsResponse\"\x00\x12j\n\x0bverifyToken\x12+.io.deephaven.proto.auth.VerifyTokenRequest\x1a,.io.deephaven.proto.auth.VerifyTokenResponse\"\x00\x12[\n\x06reload\x12&.io.deephaven.proto.auth.ReloadRequest\x1a\'.io.deephaven.proto.auth.ReloadResponse\"\x00\x12v\n\x0fverifyChallenge\x12/.io.deephaven.proto.auth.VerifyChallengeRequest\x1a\x30.io.deephaven.proto.auth.VerifyChallengeResponse\"\x00\x42\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.auth_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_AUTHAPI']._serialized_start=160
  _globals['_AUTHAPI']._serialized_end=1843
# @@protoc_insertion_point(module_scope)
