# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/controller_common.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2deephaven_enterprise/proto/controller_common.proto\x12\x1dio.deephaven.proto.controller\" \n\rErrorResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"-\n\x0bPingRequest\x12\x13\n\x06\x63ookie\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x42\t\n\x07_cookie\"\x0e\n\x0cPingResponse\"/\n\x0fNamedStringList\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\tB\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.controller_common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_ERRORRESPONSE']._serialized_start=85
  _globals['_ERRORRESPONSE']._serialized_end=117
  _globals['_PINGREQUEST']._serialized_start=119
  _globals['_PINGREQUEST']._serialized_end=164
  _globals['_PINGRESPONSE']._serialized_start=166
  _globals['_PINGRESPONSE']._serialized_end=180
  _globals['_NAMEDSTRINGLIST']._serialized_start=182
  _globals['_NAMEDSTRINGLIST']._serialized_end=229
# @@protoc_insertion_point(module_scope)
