# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%deephaven_enterprise/proto/auth.proto\x12\x17io.deephaven.proto.auth\"?\n\x0bUserContext\x12\x19\n\x11\x61uthenticatedUser\x18\x01 \x01(\t\x12\x15\n\reffectiveUser\x18\x02 \x01(\t\"&\n\x08\x43lientId\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\x0c\"\x9d\x01\n\x14\x41uthenticationResult\x12\x15\n\rauthenticated\x18\x01 \x01(\x08\x12\x0e\n\x06\x63ookie\x18\x02 \x01(\x0c\x12#\n\x1b\x63ookie_deadline_time_millis\x18\x03 \x01(\x10\x12\x39\n\x0buserContext\x18\x04 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext\"z\n\x05Token\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x0f\n\x07service\x18\x02 \x01(\t\x12:\n\x0cuser_context\x18\x03 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext\x12\x12\n\nip_address\x18\x04 \x01(\x0c\"\x92\x01\n\"AuthenticateByDelegateTokenRequest\x12\x34\n\tclient_id\x18\x01 \x01(\x0b\x32!.io.deephaven.proto.auth.ClientId\x12\x36\n\x0e\x64\x65legate_token\x18\x02 \x01(\x0b\x32\x1e.io.deephaven.proto.auth.Token\"d\n#AuthenticateByDelegateTokenResponse\x12=\n\x06result\x18\x01 \x01(\x0b\x32-.io.deephaven.proto.auth.AuthenticationResult\"&\n\x14RefreshCookieRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\"P\n\x15RefreshCookieResponse\x12\x12\n\x06\x63ookie\x18\x01 \x01(\x0c\x42\x02\x18\x01\x12#\n\x1b\x63ookie_deadline_time_millis\x18\x02 \x01(\x10\")\n\x17InvalidateCookieRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\"\x1a\n\x18InvalidateCookieResponse\"\xa3\x01\n\x1d\x41uthenticateByPasswordRequest\x12\x34\n\tclient_id\x18\x01 \x01(\x0b\x32!.io.deephaven.proto.auth.ClientId\x12:\n\x0cuser_context\x18\x02 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext\x12\x10\n\x08password\x18\x03 \x01(\t\"_\n\x1e\x41uthenticateByPasswordResponse\x12=\n\x06result\x18\x01 \x01(\x0b\x32-.io.deephaven.proto.auth.AuthenticationResult\"\xd6\x01\n\x1e\x41uthenticateByPublicKeyRequest\x12\x34\n\tclient_id\x18\x01 \x01(\x0b\x32!.io.deephaven.proto.auth.ClientId\x12:\n\x0cuser_context\x18\x02 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext\x12\x12\n\npublic_key\x18\x03 \x01(\x0c\x12\x1a\n\x12\x63hallenge_response\x18\x04 \x01(\x0c\x12\x12\n\nip_address\x18\x05 \x01(\x0c\"`\n\x1f\x41uthenticateByPublicKeyResponse\x12=\n\x06result\x18\x01 \x01(\x0b\x32-.io.deephaven.proto.auth.AuthenticationResult\"b\n\x1d\x41uthenticateByExternalRequest\x12\x34\n\tclient_id\x18\x01 \x01(\x0b\x32!.io.deephaven.proto.auth.ClientId\x12\x0b\n\x03key\x18\x02 \x01(\t\"_\n\x1e\x41uthenticateByExternalResponse\x12=\n\x06result\x18\x01 \x01(\x0b\x32-.io.deephaven.proto.auth.AuthenticationResult\"\x9f\x01\n\x1b\x41uthenticateByCookieRequest\x12\x34\n\tclient_id\x18\x01 \x01(\x0b\x32!.io.deephaven.proto.auth.ClientId\x12:\n\x0cuser_context\x18\x02 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext\x12\x0e\n\x06\x63ookie\x18\x03 \x01(\x0c\"]\n\x1c\x41uthenticateByCookieResponse\x12=\n\x06result\x18\x01 \x01(\x0b\x32-.io.deephaven.proto.auth.AuthenticationResult\"G\n\x0fGetNonceRequest\x12\x34\n\tclient_id\x18\x01 \x01(\x0b\x32!.io.deephaven.proto.auth.ClientId\"5\n\x10GetNonceResponse\x12\r\n\x05nonce\x18\x01 \x01(\x0c\x12\x12\n\nip_address\x18\x02 \x01(\x0c\"2\n\x0fGetTokenRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x0f\n\x07service\x18\x02 \x01(\t\"A\n\x10GetTokenResponse\x12-\n\x05token\x18\x01 \x01(\x0b\x32\x1e.io.deephaven.proto.auth.Token\"K\n\x11GetTokenAsRequest\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\x0c\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x15\n\roperateAsUser\x18\x03 \x01(\t\"C\n\x12GetTokenAsResponse\x12-\n\x05token\x18\x01 \x01(\x0b\x32\x1e.io.deephaven.proto.auth.Token\"T\n\x12VerifyTokenRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\x12-\n\x05token\x18\x02 \x01(\x0b\x32\x1e.io.deephaven.proto.auth.Token\"*\n\x13VerifyTokenResponse\x12\x13\n\x0btoken_valid\x18\x01 \x01(\x08\"\x0f\n\rReloadRequest\" \n\x0eReloadResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"_\n\x0cKvClientData\x12\x14\n\x0chashedCookie\x18\x01 \x01(\x0c\x12\x39\n\x0buserContext\x18\x02 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext\"U\n\tAuthError\x12\x37\n\ncallStatus\x18\x01 \x01(\x0e\x32#.io.deephaven.proto.auth.CallStatus\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xd5\x01\n\x16VerifyChallengeRequest\x12\x19\n\x11server_ip_address\x18\x01 \x01(\x0c\x12\x34\n\tclient_id\x18\x02 \x01(\x0b\x32!.io.deephaven.proto.auth.ClientId\x12:\n\x0cuser_context\x18\x03 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext\x12\x12\n\npublic_key\x18\x04 \x01(\x0c\x12\x1a\n\x12\x63hallenge_response\x18\x05 \x01(\x0c\"e\n\x17VerifyChallengeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x39\n\x0buserContext\x18\x02 \x01(\x0b\x32$.io.deephaven.proto.auth.UserContext*\xcd\x01\n\nCallStatus\x12\x06\n\x02OK\x10\x00\x12\x1c\n\x18\x41UTH_ERROR_NON_RETRYABLE\x10\x01\x12\x18\n\x14\x41UTH_ERROR_RETRYABLE\x10\x02\x12\x19\n\x15\x41LREADY_AUTHENTICATED\x10\x03\x12\x15\n\x11NOT_AUTHENTICATED\x10\x04\x12\x10\n\x0cPUB_PRIV_KEY\x10\x05\x12\x12\n\x0eTOKEN_CREATION\x10\x06\x12\x16\n\x12TOKEN_VERIFICATION\x10\x07\x12\x0f\n\x0bUNAVAILABLE\x10\x08\x42\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_REFRESHCOOKIERESPONSE'].fields_by_name['cookie']._loaded_options = None
  _globals['_REFRESHCOOKIERESPONSE'].fields_by_name['cookie']._serialized_options = b'\030\001'
  _globals['_CALLSTATUS']._serialized_start=3009
  _globals['_CALLSTATUS']._serialized_end=3214
  _globals['_USERCONTEXT']._serialized_start=66
  _globals['_USERCONTEXT']._serialized_end=129
  _globals['_CLIENTID']._serialized_start=131
  _globals['_CLIENTID']._serialized_end=169
  _globals['_AUTHENTICATIONRESULT']._serialized_start=172
  _globals['_AUTHENTICATIONRESULT']._serialized_end=329
  _globals['_TOKEN']._serialized_start=331
  _globals['_TOKEN']._serialized_end=453
  _globals['_AUTHENTICATEBYDELEGATETOKENREQUEST']._serialized_start=456
  _globals['_AUTHENTICATEBYDELEGATETOKENREQUEST']._serialized_end=602
  _globals['_AUTHENTICATEBYDELEGATETOKENRESPONSE']._serialized_start=604
  _globals['_AUTHENTICATEBYDELEGATETOKENRESPONSE']._serialized_end=704
  _globals['_REFRESHCOOKIEREQUEST']._serialized_start=706
  _globals['_REFRESHCOOKIEREQUEST']._serialized_end=744
  _globals['_REFRESHCOOKIERESPONSE']._serialized_start=746
  _globals['_REFRESHCOOKIERESPONSE']._serialized_end=826
  _globals['_INVALIDATECOOKIEREQUEST']._serialized_start=828
  _globals['_INVALIDATECOOKIEREQUEST']._serialized_end=869
  _globals['_INVALIDATECOOKIERESPONSE']._serialized_start=871
  _globals['_INVALIDATECOOKIERESPONSE']._serialized_end=897
  _globals['_AUTHENTICATEBYPASSWORDREQUEST']._serialized_start=900
  _globals['_AUTHENTICATEBYPASSWORDREQUEST']._serialized_end=1063
  _globals['_AUTHENTICATEBYPASSWORDRESPONSE']._serialized_start=1065
  _globals['_AUTHENTICATEBYPASSWORDRESPONSE']._serialized_end=1160
  _globals['_AUTHENTICATEBYPUBLICKEYREQUEST']._serialized_start=1163
  _globals['_AUTHENTICATEBYPUBLICKEYREQUEST']._serialized_end=1377
  _globals['_AUTHENTICATEBYPUBLICKEYRESPONSE']._serialized_start=1379
  _globals['_AUTHENTICATEBYPUBLICKEYRESPONSE']._serialized_end=1475
  _globals['_AUTHENTICATEBYEXTERNALREQUEST']._serialized_start=1477
  _globals['_AUTHENTICATEBYEXTERNALREQUEST']._serialized_end=1575
  _globals['_AUTHENTICATEBYEXTERNALRESPONSE']._serialized_start=1577
  _globals['_AUTHENTICATEBYEXTERNALRESPONSE']._serialized_end=1672
  _globals['_AUTHENTICATEBYCOOKIEREQUEST']._serialized_start=1675
  _globals['_AUTHENTICATEBYCOOKIEREQUEST']._serialized_end=1834
  _globals['_AUTHENTICATEBYCOOKIERESPONSE']._serialized_start=1836
  _globals['_AUTHENTICATEBYCOOKIERESPONSE']._serialized_end=1929
  _globals['_GETNONCEREQUEST']._serialized_start=1931
  _globals['_GETNONCEREQUEST']._serialized_end=2002
  _globals['_GETNONCERESPONSE']._serialized_start=2004
  _globals['_GETNONCERESPONSE']._serialized_end=2057
  _globals['_GETTOKENREQUEST']._serialized_start=2059
  _globals['_GETTOKENREQUEST']._serialized_end=2109
  _globals['_GETTOKENRESPONSE']._serialized_start=2111
  _globals['_GETTOKENRESPONSE']._serialized_end=2176
  _globals['_GETTOKENASREQUEST']._serialized_start=2178
  _globals['_GETTOKENASREQUEST']._serialized_end=2253
  _globals['_GETTOKENASRESPONSE']._serialized_start=2255
  _globals['_GETTOKENASRESPONSE']._serialized_end=2322
  _globals['_VERIFYTOKENREQUEST']._serialized_start=2324
  _globals['_VERIFYTOKENREQUEST']._serialized_end=2408
  _globals['_VERIFYTOKENRESPONSE']._serialized_start=2410
  _globals['_VERIFYTOKENRESPONSE']._serialized_end=2452
  _globals['_RELOADREQUEST']._serialized_start=2454
  _globals['_RELOADREQUEST']._serialized_end=2469
  _globals['_RELOADRESPONSE']._serialized_start=2471
  _globals['_RELOADRESPONSE']._serialized_end=2503
  _globals['_KVCLIENTDATA']._serialized_start=2505
  _globals['_KVCLIENTDATA']._serialized_end=2600
  _globals['_AUTHERROR']._serialized_start=2602
  _globals['_AUTHERROR']._serialized_end=2687
  _globals['_VERIFYCHALLENGEREQUEST']._serialized_start=2690
  _globals['_VERIFYCHALLENGEREQUEST']._serialized_end=2903
  _globals['_VERIFYCHALLENGERESPONSE']._serialized_start=2905
  _globals['_VERIFYCHALLENGERESPONSE']._serialized_end=3006
# @@protoc_insertion_point(module_scope)
