# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deephaven_enterprise/proto/persistent_query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deephaven_enterprise.proto import common_pb2 as deephaven__enterprise_dot_proto_dot_common__pb2
from deephaven_enterprise.proto import controller_common_pb2 as deephaven__enterprise_dot_proto_dot_controller__common__pb2
from deephaven_enterprise.proto import table_definition_pb2 as deephaven__enterprise_dot_proto_dot_table__definition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1deephaven_enterprise/proto/persistent_query.proto\x12\x1dio.deephaven.proto.controller\x1a\'deephaven_enterprise/proto/common.proto\x1a\x32\x64\x65\x65phaven_enterprise/proto/controller_common.proto\x1a\x31\x64\x65\x65phaven_enterprise/proto/table_definition.proto\"\xc6\x08\n\x1cPersistentQueryConfigMessage\x12\x0e\n\x06serial\x18\x01 \x01(\x03\x12\x0f\n\x07version\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x12\n\nheapSizeGb\x18\x06 \x01(\x01\x12\x1d\n\x15\x62ufferPoolToHeapRatio\x18\x07 \x01(\x01\x12 \n\x18\x64\x65tailedGCLoggingEnabled\x18\x08 \x01(\x08\x12\x19\n\x11\x65xtraJvmArguments\x18\t \x03(\t\x12!\n\x19\x65xtraEnvironmentVariables\x18\n \x03(\t\x12\x1a\n\x12\x63lassPathAdditions\x18\x0b \x03(\t\x12\x12\n\nserverName\x18\x0c \x01(\t\x12\x13\n\x0b\x61\x64minGroups\x18\r \x03(\t\x12\x14\n\x0cviewerGroups\x18\x0e \x03(\t\x12\x45\n\x0crestartUsers\x18\x0f \x01(\x0e\x32/.io.deephaven.proto.controller.RestartUsersEnum\x12\x14\n\nscriptCode\x18\x10 \x01(\tH\x00\x12\x14\n\nscriptPath\x18\x11 \x01(\tH\x00\x12\x16\n\x0escriptLanguage\x18\x12 \x01(\t\x12\x19\n\x11\x63onfigurationType\x18\x13 \x01(\t\x12#\n\x16typeSpecificFieldsJson\x18\x14 \x01(\tH\x01\x88\x01\x01\x12\x12\n\nscheduling\x18\x15 \x03(\t\x12\x14\n\x0ctimeoutNanos\x18\x16 \x01(\x03\x12\x12\n\njvmProfile\x18\x17 \x01(\t\x12#\n\x1blastModifiedByAuthenticated\x18\x18 \x01(\t\x12\x1f\n\x17lastModifiedByEffective\x18\x19 \x01(\t\x12\x1d\n\x15lastModifiedTimeNanos\x18\x1a \x01(\x03\x12\x17\n\x0f\x63ompletedStatus\x18\x1b \x01(\t\x12\x1b\n\x13\x65xpirationTimeNanos\x18\x1c \x01(\x03\x12\x19\n\x11kubernetesControl\x18\x1d \x01(\t\x12\x12\n\nworkerKind\x18\x1e \x01(\t\x12\x18\n\x10\x63reatedTimeNanos\x18\x1f \x01(\x03\x12\x14\n\x0creplicaCount\x18  \x01(\x05\x12\x12\n\nspareCount\x18! \x01(\x05\x12\x18\n\x10\x61ssignmentPolicy\x18\" \x01(\t\x12#\n\x16\x61ssignmentPolicyParams\x18# \x01(\tH\x02\x88\x01\x01\x12\x1a\n\x12\x61\x64\x64itionalMemoryGb\x18$ \x01(\x01\x12\x15\n\rpythonControl\x18% \x01(\t\x12\x1c\n\x14genericWorkerControl\x18& \x01(\tB\x0c\n\nscriptDataB\x19\n\x17_typeSpecificFieldsJsonB\x19\n\x17_assignmentPolicyParams\"\xd0\x01\n\x19\x45xportedObjectInfoMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\x04type\x18\x02 \x01(\x0e\x32\x35.io.deephaven.proto.controller.ExportedObjectTypeEnum\x12J\n\x0ftableDefinition\x18\x03 \x01(\x0b\x32\x31.io.deephaven.proto.common.TableDefinitionMessage\x12\x14\n\x0coriginalType\x18\x04 \x01(\t\"3\n\x15WorkerProtocolMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\x87\x02\n!ProcessorConnectionDetailsMessage\x12G\n\tprotocols\x18\x01 \x03(\x0b\x32\x34.io.deephaven.proto.controller.WorkerProtocolMessage\x12\x12\n\nworkerName\x18\x02 \x01(\t\x12\x15\n\rprocessInfoId\x18\x03 \x01(\t\x12\x15\n\rprocessorHost\x18\x04 \x01(\t\x12\x13\n\x0b\x65nvoyPrefix\x18\x05 \x01(\t\x12\x0f\n\x07grpcUrl\x18\x06 \x01(\t\x12\x11\n\tstaticUrl\x18\x07 \x01(\t\x12\x1e\n\x16\x65nterpriseWebSocketUrl\x18\x08 \x01(\t\"\xf6\x07\n\x1bPersistentQueryStateMessage\x12\x0e\n\x06serial\x18\x01 \x01(\x03\x12\x0f\n\x07version\x18\x02 \x01(\x03\x12H\n\x06status\x18\x03 \x01(\x0e\x32\x38.io.deephaven.proto.controller.PersistentQueryStatusEnum\x12 \n\x18initializationStartNanos\x18\x04 \x01(\x03\x12#\n\x1binitializationCompleteNanos\x18\x05 \x01(\x03\x12\x17\n\x0flastUpdateNanos\x18\x06 \x01(\x03\x12\x16\n\x0e\x64ispatcherHost\x18\x07 \x01(\t\x12\x43\n\x0btableGroups\x18\x08 \x03(\x0b\x32..io.deephaven.proto.controller.NamedStringList\x12L\n\nscopeTypes\x18\t \x03(\x0b\x32\x38.io.deephaven.proto.controller.ExportedObjectInfoMessage\x12`\n\x11\x63onnectionDetails\x18\n \x01(\x0b\x32@.io.deephaven.proto.controller.ProcessorConnectionDetailsMessageH\x00\x88\x01\x01\x12Q\n\x10\x65xceptionDetails\x18\x0b \x01(\x0b\x32\x32.io.deephaven.proto.common.ExceptionDetailsMessageH\x01\x88\x01\x01\x12\x1d\n\x15typeSpecificStateJson\x18\x0c \x01(\t\x12\x1d\n\x15lastAuthenticatedUser\x18\r \x01(\t\x12\x19\n\x11lastEffectiveUser\x18\x0e \x01(\t\x12\"\n\x15scriptLoaderStateJson\x18\x0f \x01(\tH\x02\x88\x01\x01\x12\x13\n\x0bhasProgress\x18\x10 \x01(\x08\x12\x15\n\rprogressValue\x18\x11 \x01(\x05\x12\x17\n\x0fprogressMessage\x18\x12 \x01(\t\x12\x15\n\rengineVersion\x18\x13 \x01(\t\x12\x16\n\x0e\x64ispatcherPort\x18\x14 \x01(\x05\x12\x17\n\x0fshouldStopNanos\x18\x15 \x01(\x03\x12\x13\n\x0bnumFailures\x18\x16 \x01(\x05\x12\x1c\n\x14lastFailureTimeNanos\x18\x17 \x01(\x03\x12\x13\n\x0breplicaSlot\x18\x18 \x01(\x05\x12\x15\n\rstatusDetails\x18\x19 \x01(\tB\x14\n\x12_connectionDetailsB\x13\n\x11_exceptionDetailsB\x18\n\x16_scriptLoaderStateJson\"\xe9\x02\n\x1aPersistentQueryInfoMessage\x12K\n\x06\x63onfig\x18\x01 \x01(\x0b\x32;.io.deephaven.proto.controller.PersistentQueryConfigMessage\x12N\n\x05state\x18\x02 \x01(\x0b\x32:.io.deephaven.proto.controller.PersistentQueryStateMessageH\x00\x88\x01\x01\x12L\n\x08replicas\x18\x05 \x03(\x0b\x32:.io.deephaven.proto.controller.PersistentQueryStateMessage\x12J\n\x06spares\x18\x06 \x03(\x0b\x32:.io.deephaven.proto.controller.PersistentQueryStateMessageB\x08\n\x06_stateJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05*{\n\x10RestartUsersEnum\x12\x12\n\x0eRU_UNSPECIFIED\x10\x00\x12\x0c\n\x08RU_ADMIN\x10\x01\x12\x18\n\x14RU_ADMIN_AND_VIEWERS\x10\x02\x12\x11\n\rRU_RESERVED_1\x10\x03\x12\x18\n\x14RU_VIEWERS_WHEN_DOWN\x10\x04*\xb2\x02\n\x19PersistentQueryStatusEnum\x12\x13\n\x0fPQS_UNSPECIFIED\x10\x00\x12\x15\n\x11PQS_UNINITIALIZED\x10\x01\x12\x12\n\x0ePQS_CONNECTING\x10\x02\x12\x16\n\x12PQS_AUTHENTICATING\x10\x03\x12\x18\n\x14PQS_ACQUIRING_WORKER\x10\x04\x12\x14\n\x10PQS_INITIALIZING\x10\x05\x12\x0f\n\x0bPQS_RUNNING\x10\x06\x12\x0e\n\nPQS_FAILED\x10\x07\x12\r\n\tPQS_ERROR\x10\x08\x12\x14\n\x10PQS_DISCONNECTED\x10\t\x12\x10\n\x0cPQS_STOPPING\x10\n\x12\x0f\n\x0bPQS_STOPPED\x10\x0b\x12\x11\n\rPQS_COMPLETED\x10\x0c\x12\x11\n\rPQS_EXECUTING\x10\r*\xcf\x01\n\x16\x45xportedObjectTypeEnum\x12\x13\n\x0f\x45OT_UNSPECIFIED\x10\x00\x12\r\n\tEOT_TABLE\x10\x01\x12\x12\n\x0e\x45OT_TREE_TABLE\x10\x02\x12\x11\n\rEOT_TABLE_MAP\x10\x03\x12\x0e\n\nEOT_FIGURE\x10\x04\x12\x14\n\x10\x45OT_OTHER_WIDGET\x10\x05\x12\x1b\n\x17\x45OT_PARAMETERIZED_QUERY\x10\x06\x12\x0e\n\nEOT_PANDAS\x10\x07\x12\x17\n\x13\x45OT_NON_DISPLAYABLE\x10\x08\x42\x04H\x01P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deephaven_enterprise.proto.persistent_query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\001P\001'
  _globals['_RESTARTUSERSENUM']._serialized_start=3236
  _globals['_RESTARTUSERSENUM']._serialized_end=3359
  _globals['_PERSISTENTQUERYSTATUSENUM']._serialized_start=3362
  _globals['_PERSISTENTQUERYSTATUSENUM']._serialized_end=3668
  _globals['_EXPORTEDOBJECTTYPEENUM']._serialized_start=3671
  _globals['_EXPORTEDOBJECTTYPEENUM']._serialized_end=3878
  _globals['_PERSISTENTQUERYCONFIGMESSAGE']._serialized_start=229
  _globals['_PERSISTENTQUERYCONFIGMESSAGE']._serialized_end=1323
  _globals['_EXPORTEDOBJECTINFOMESSAGE']._serialized_start=1326
  _globals['_EXPORTEDOBJECTINFOMESSAGE']._serialized_end=1534
  _globals['_WORKERPROTOCOLMESSAGE']._serialized_start=1536
  _globals['_WORKERPROTOCOLMESSAGE']._serialized_end=1587
  _globals['_PROCESSORCONNECTIONDETAILSMESSAGE']._serialized_start=1590
  _globals['_PROCESSORCONNECTIONDETAILSMESSAGE']._serialized_end=1853
  _globals['_PERSISTENTQUERYSTATEMESSAGE']._serialized_start=1856
  _globals['_PERSISTENTQUERYSTATEMESSAGE']._serialized_end=2870
  _globals['_PERSISTENTQUERYINFOMESSAGE']._serialized_start=2873
  _globals['_PERSISTENTQUERYINFOMESSAGE']._serialized_end=3234
# @@protoc_insertion_point(module_scope)
