# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from deephaven_enterprise.proto import acl_pb2 as deephaven__enterprise_dot_proto_dot_acl__pb2
from deephaven_enterprise.proto import auth_pb2 as deephaven__enterprise_dot_proto_dot_auth__pb2
from deephaven_enterprise.proto import controller_common_pb2 as deephaven__enterprise_dot_proto_dot_controller__common__pb2
from deephaven_enterprise.proto import controller_pb2 as deephaven__enterprise_dot_proto_dot_controller__pb2

GRPC_GENERATED_VERSION = '1.63.0'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in deephaven_enterprise/proto/controller_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class ControllerApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.authenticate = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/authenticate',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.AuthenticationRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.AuthenticationResponse.FromString,
                _registered_method=True)
        self.addQuery = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/addQuery',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.AddQueryRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.AddQueryResponse.FromString,
                _registered_method=True)
        self.removeQuery = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/removeQuery',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RemoveQueryRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RemoveQueryResponse.FromString,
                _registered_method=True)
        self.modifyQuery = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/modifyQuery',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ModifyQueryRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ModifyQueryResponse.FromString,
                _registered_method=True)
        self.restartQuery = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/restartQuery',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RestartQueryRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RestartQueryResponse.FromString,
                _registered_method=True)
        self.stopQuery = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/stopQuery',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StopQueryRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StopQueryResponse.FromString,
                _registered_method=True)
        self.restartReplica = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/restartReplica',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RestartReplicaRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RestartReplicaResponse.FromString,
                _registered_method=True)
        self.stopReplica = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/stopReplica',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StopReplicaRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StopReplicaResponse.FromString,
                _registered_method=True)
        self.determineDispatcher = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/determineDispatcher',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.DetermineDispatcherRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.DetermineDispatcherResponse.FromString,
                _registered_method=True)
        self.selectionProviderStatus = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/selectionProviderStatus',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionStatusRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionStatusResponse.FromString,
                _registered_method=True)
        self.selectionProviderAdmin = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/selectionProviderAdmin',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionAdminRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionAdminResponse.FromString,
                _registered_method=True)
        self.getConfiguration = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/getConfiguration',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetConfigurationRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetConfigurationResponse.FromString,
                _registered_method=True)
        self.getScriptPaths = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/getScriptPaths',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptPathsRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptPathsResponse.FromString,
                _registered_method=True)
        self.getScript = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/getScript',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptResponse.FromString,
                _registered_method=True)
        self.statusUpdate = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/statusUpdate',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StatusUpdateRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StatusUpdateResponse.FromString,
                _registered_method=True)
        self.reloadConfig = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/reloadConfig',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ReloadConfigRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ReloadConfigResponse.FromString,
                _registered_method=True)
        self.ping = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/ping',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__common__pb2.PingRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__common__pb2.PingResponse.FromString,
                _registered_method=True)
        self.subscribe = channel.unary_stream(
                '/io.deephaven.proto.controller.grpc.ControllerApi/subscribe',
                request_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.SubscribeRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.SubscribeResponse.FromString,
                _registered_method=True)
        self.invalidateCookie = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.ControllerApi/invalidateCookie',
                request_serializer=deephaven__enterprise_dot_proto_dot_auth__pb2.InvalidateCookieRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_auth__pb2.InvalidateCookieResponse.FromString,
                _registered_method=True)


class ControllerApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def authenticate(self, request, context):
        """Authentication
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def addQuery(self, request, context):
        """These are for query management
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def modifyQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def restartQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def restartReplica(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopReplica(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def determineDispatcher(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def selectionProviderStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def selectionProviderAdmin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getScriptPaths(self, request, context):
        """Script commands
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getScript(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def statusUpdate(self, request, context):
        """Configuration commands
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def reloadConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ping(self, request, context):
        """Heartbeating
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def invalidateCookie(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ControllerApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'authenticate': grpc.unary_unary_rpc_method_handler(
                    servicer.authenticate,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.AuthenticationRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.AuthenticationResponse.SerializeToString,
            ),
            'addQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.addQuery,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.AddQueryRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.AddQueryResponse.SerializeToString,
            ),
            'removeQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.removeQuery,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RemoveQueryRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RemoveQueryResponse.SerializeToString,
            ),
            'modifyQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.modifyQuery,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ModifyQueryRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ModifyQueryResponse.SerializeToString,
            ),
            'restartQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.restartQuery,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RestartQueryRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RestartQueryResponse.SerializeToString,
            ),
            'stopQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.stopQuery,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StopQueryRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StopQueryResponse.SerializeToString,
            ),
            'restartReplica': grpc.unary_unary_rpc_method_handler(
                    servicer.restartReplica,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RestartReplicaRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.RestartReplicaResponse.SerializeToString,
            ),
            'stopReplica': grpc.unary_unary_rpc_method_handler(
                    servicer.stopReplica,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StopReplicaRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StopReplicaResponse.SerializeToString,
            ),
            'determineDispatcher': grpc.unary_unary_rpc_method_handler(
                    servicer.determineDispatcher,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.DetermineDispatcherRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.DetermineDispatcherResponse.SerializeToString,
            ),
            'selectionProviderStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.selectionProviderStatus,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionStatusRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionStatusResponse.SerializeToString,
            ),
            'selectionProviderAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.selectionProviderAdmin,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionAdminRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionAdminResponse.SerializeToString,
            ),
            'getConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.getConfiguration,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetConfigurationRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetConfigurationResponse.SerializeToString,
            ),
            'getScriptPaths': grpc.unary_unary_rpc_method_handler(
                    servicer.getScriptPaths,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptPathsRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptPathsResponse.SerializeToString,
            ),
            'getScript': grpc.unary_unary_rpc_method_handler(
                    servicer.getScript,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptResponse.SerializeToString,
            ),
            'statusUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.statusUpdate,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StatusUpdateRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.StatusUpdateResponse.SerializeToString,
            ),
            'reloadConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.reloadConfig,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ReloadConfigRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.ReloadConfigResponse.SerializeToString,
            ),
            'ping': grpc.unary_unary_rpc_method_handler(
                    servicer.ping,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__common__pb2.PingRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__common__pb2.PingResponse.SerializeToString,
            ),
            'subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribe,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_controller__pb2.SubscribeRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_controller__pb2.SubscribeResponse.SerializeToString,
            ),
            'invalidateCookie': grpc.unary_unary_rpc_method_handler(
                    servicer.invalidateCookie,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_auth__pb2.InvalidateCookieRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_auth__pb2.InvalidateCookieResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'io.deephaven.proto.controller.grpc.ControllerApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ControllerApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def authenticate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/authenticate',
            deephaven__enterprise_dot_proto_dot_controller__pb2.AuthenticationRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.AuthenticationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def addQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/addQuery',
            deephaven__enterprise_dot_proto_dot_controller__pb2.AddQueryRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.AddQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def removeQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/removeQuery',
            deephaven__enterprise_dot_proto_dot_controller__pb2.RemoveQueryRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.RemoveQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def modifyQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/modifyQuery',
            deephaven__enterprise_dot_proto_dot_controller__pb2.ModifyQueryRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.ModifyQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def restartQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/restartQuery',
            deephaven__enterprise_dot_proto_dot_controller__pb2.RestartQueryRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.RestartQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def stopQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/stopQuery',
            deephaven__enterprise_dot_proto_dot_controller__pb2.StopQueryRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.StopQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def restartReplica(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/restartReplica',
            deephaven__enterprise_dot_proto_dot_controller__pb2.RestartReplicaRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.RestartReplicaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def stopReplica(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/stopReplica',
            deephaven__enterprise_dot_proto_dot_controller__pb2.StopReplicaRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.StopReplicaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def determineDispatcher(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/determineDispatcher',
            deephaven__enterprise_dot_proto_dot_controller__pb2.DetermineDispatcherRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.DetermineDispatcherResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def selectionProviderStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/selectionProviderStatus',
            deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionStatusRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def selectionProviderAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/selectionProviderAdmin',
            deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionAdminRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.ServerSelectionAdminResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/getConfiguration',
            deephaven__enterprise_dot_proto_dot_controller__pb2.GetConfigurationRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.GetConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getScriptPaths(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/getScriptPaths',
            deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptPathsRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptPathsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getScript(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/getScript',
            deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.GetScriptResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def statusUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/statusUpdate',
            deephaven__enterprise_dot_proto_dot_controller__pb2.StatusUpdateRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.StatusUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def reloadConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/reloadConfig',
            deephaven__enterprise_dot_proto_dot_controller__pb2.ReloadConfigRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.ReloadConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/ping',
            deephaven__enterprise_dot_proto_dot_controller__common__pb2.PingRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__common__pb2.PingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/subscribe',
            deephaven__enterprise_dot_proto_dot_controller__pb2.SubscribeRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_controller__pb2.SubscribeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def invalidateCookie(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.ControllerApi/invalidateCookie',
            deephaven__enterprise_dot_proto_dot_auth__pb2.InvalidateCookieRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_auth__pb2.InvalidateCookieResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class AclApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.isSuperUser = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.AclApi/isSuperUser',
                request_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.FromString,
                _registered_method=True)
        self.isAclEditor = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.AclApi/isAclEditor',
                request_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.FromString,
                _registered_method=True)
        self.isQueryManager = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.AclApi/isQueryManager',
                request_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.FromString,
                _registered_method=True)
        self.isSchemaManager = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.AclApi/isSchemaManager',
                request_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.FromString,
                _registered_method=True)
        self.getUsersForGroup = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.AclApi/getUsersForGroup',
                request_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryGroupRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.FromString,
                _registered_method=True)
        self.getGroupsForUser = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.AclApi/getGroupsForUser',
                request_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.FromString,
                _registered_method=True)
        self.getAllUsers = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.AclApi/getAllUsers',
                request_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.GetAllUsersRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.FromString,
                _registered_method=True)
        self.getAllGroups = channel.unary_unary(
                '/io.deephaven.proto.controller.grpc.AclApi/getAllGroups',
                request_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.GetAllGroupsRequest.SerializeToString,
                response_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.FromString,
                _registered_method=True)


class AclApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def isSuperUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def isAclEditor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def isQueryManager(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def isSchemaManager(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getUsersForGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getGroupsForUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAllUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAllGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AclApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'isSuperUser': grpc.unary_unary_rpc_method_handler(
                    servicer.isSuperUser,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.SerializeToString,
            ),
            'isAclEditor': grpc.unary_unary_rpc_method_handler(
                    servicer.isAclEditor,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.SerializeToString,
            ),
            'isQueryManager': grpc.unary_unary_rpc_method_handler(
                    servicer.isQueryManager,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.SerializeToString,
            ),
            'isSchemaManager': grpc.unary_unary_rpc_method_handler(
                    servicer.isSchemaManager,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.SerializeToString,
            ),
            'getUsersForGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.getUsersForGroup,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryGroupRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.SerializeToString,
            ),
            'getGroupsForUser': grpc.unary_unary_rpc_method_handler(
                    servicer.getGroupsForUser,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.SerializeToString,
            ),
            'getAllUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.getAllUsers,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.GetAllUsersRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.SerializeToString,
            ),
            'getAllGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.getAllGroups,
                    request_deserializer=deephaven__enterprise_dot_proto_dot_acl__pb2.GetAllGroupsRequest.FromString,
                    response_serializer=deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'io.deephaven.proto.controller.grpc.AclApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AclApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def isSuperUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.AclApi/isSuperUser',
            deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def isAclEditor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.AclApi/isAclEditor',
            deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def isQueryManager(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.AclApi/isQueryManager',
            deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def isSchemaManager(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.AclApi/isSchemaManager',
            deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_acl__pb2.BooleanResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getUsersForGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.AclApi/getUsersForGroup',
            deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryGroupRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getGroupsForUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.AclApi/getGroupsForUser',
            deephaven__enterprise_dot_proto_dot_acl__pb2.UnaryUserRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getAllUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.AclApi/getAllUsers',
            deephaven__enterprise_dot_proto_dot_acl__pb2.GetAllUsersRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getAllGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/io.deephaven.proto.controller.grpc.AclApi/getAllGroups',
            deephaven__enterprise_dot_proto_dot_acl__pb2.GetAllGroupsRequest.SerializeToString,
            deephaven__enterprise_dot_proto_dot_acl__pb2.UserOrGroupList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
